pub enum ErrorReason {
MCS_MALFORMED_JSON,
MCS_MEDIA_FAILED_TO_DECRYPT,
M_MISSING_TOKEN,
M_UNKNOWN_TOKEN,
M_NOT_FOUND,
MCS_MEDIA_NOT_CLEAN,
MCS_MIME_TYPE_FORBIDDEN,
MCS_BAD_DECRYPTION,
M_UNKNOWN,
MCS_MEDIA_REQUEST_FAILED,
}Expand description
The reason for the content scanner error.
Variants
MCS_MALFORMED_JSON
The JSON file is malformed.
MCS_MEDIA_FAILED_TO_DECRYPT
The media could not be decrypted.
M_MISSING_TOKEN
No access token was provided.
M_UNKNOWN_TOKEN
The access token provided is invalid.
M_NOT_FOUND
The media was not found.
MCS_MEDIA_NOT_CLEAN
The media has some potentially dangerous content.
MCS_MIME_TYPE_FORBIDDEN
The media has been blocked by the server because of its mime type.
MCS_BAD_DECRYPTION
The used public key is wrong.
M_UNKNOWN
An unknown error occurred.
MCS_MEDIA_REQUEST_FAILED
The server failed to request media from the media repo.