pub struct MediaScanResponse {
pub clean: bool,
pub info: String,
}Expand description
A media scan response containing the result of the scan. Spec: https://github.com/element-hq/matrix-content-scanner-python/blob/main/docs/api.md#get-_matrixmedia_proxyunstablescanservernamemediaid
Fields
clean: boolWhether the media is clean or contained something dangerous.
info: StringExtra information about the scan.